@@ -172,7 +172,6 @@ class OBDPort:
          """ Resets device and closes all associated filehandles"""
          
          if (self.port!= None) and self.State==1:
-            print "Send atz"
             self.send_command("atz")
             time.sleep(0.1)
             self.port.close()
@@ -183,15 +182,15 @@ class OBDPort:
      def send_command(self, cmd):
          """Internal use only: not a public interface"""
          if self.port:
-             time.sleep(0.3)
+             time.sleep(0.16)
              self.port.flushOutput()
              self.port.flushInput()
              for c in cmd:
                  self.port.write(c)
              self.port.write("\r\n")
+             time.sleep(0.1)
              wx.PostEvent(self._notify_window, DebugEvent([3,"Send command:" + cmd]))
              print "Send: " + cmd
-             time.sleep(0.3)
 
      def interpret_result(self,code):
          """Internal use only: not a public interface"""
