@@ -55,11 +55,11 @@ import hildon
 
 from wx.lib.mixins.listctrl import ListCtrlAutoWidthMixin
 
-
 _fromUtf8 = lambda s: s
 
 ID_ABOUT  = 101
 ID_EXIT   = 110
+ID_FULLSCREEN  = 111
 ID_CONFIG = 500
 ID_CLEAR  = 501
 ID_GETC   = 502
@@ -137,8 +137,8 @@ from debugEvent import *
 class MyApp(wx.App):
     # A listctrl which auto-resizes the column boxes to fill
     class MyListCtrl(wx.ListCtrl, ListCtrlAutoWidthMixin):
-        def __init__(self, parent, id, pos = wx.DefaultPosition,
-                     size = wx.DefaultSize, style = 0):
+        def __init__(self, parent, id, pos = wx.DefaultPosition, size = wx.DefaultSize, style = 0):
+
             wx.ListCtrl.__init__(self,parent,id,pos,size,style)
             ListCtrlAutoWidthMixin.__init__(self)
 
@@ -175,10 +175,6 @@ class MyApp(wx.App):
             self.supp1  = self.port.sensor(32)[1] #read supported PIDS2x
             self.supp2  = self.port.sensor(64)[1] #read supported PIDS3x
 
-            #print "self.supp  " + (self.supp)
-            #print "self.supp1 " + (self.supp1)
-            #print "self.supp2 " + (self.supp2)
-
             self.supp = str(self.supp+self.supp1+self.supp2)
 
             print "self.sup f: " + self.supp
@@ -202,7 +198,6 @@ class MyApp(wx.App):
         def run(self):
             global btname
 
-
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connecting...."]))
             try:
                self.initCommunication()
@@ -222,7 +217,6 @@ class MyApp(wx.App):
             wx.PostEvent(self._notify_window, StatusEvent([3,1,self.portName]))
             wx.PostEvent(self._notify_window, StatusEvent([4,1,btname]))
 
-
             os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connected to ECU"')
 
             log2="echo Connected > /home/user/MyDocs/pyobd.log"
@@ -230,8 +224,6 @@ class MyApp(wx.App):
             log2="echo >> /home/user/MyDocs/pyobd.log"
             os.popen(log2)
 
-
-
             wx.PostEvent(self._notify_window, StatusEvent([2,1,self.port.ELMver]))
             prevstate=-1
             curstate=-1
@@ -262,10 +254,6 @@ class MyApp(wx.App):
 
                   for i in range(3, len(self.active)):
 
-
-                      #print "active pid "+str(self.active)
-
-
                       if self.active[i]:
                           s = self.port.sensor(i)
                           wx.PostEvent(self._notify_window, ResultEvent([i,2,"%s (%s)" % (s[1], s[2])]))
@@ -277,8 +265,6 @@ class MyApp(wx.App):
                           log2="echo  >> /home/user/MyDocs/pyobd.log"
                           os.popen(log2)
 
-
-
                       if self._notify_window.ThreadControl==666:
                           break
                 elif curstate==3: #show DTC tab
@@ -448,7 +434,6 @@ class MyApp(wx.App):
                                   wx.SUNKEN_BORDER |
                                   wx.LC_HRULES     |
                                   wx.LC_SINGLE_SEL)
-     
 
         self.sensors.InsertColumn(0, "S.",width=40)
         self.sensors.InsertColumn(1, "Sensor",format=wx.LIST_FORMAT_CENTER, width=400)
@@ -519,7 +504,6 @@ class MyApp(wx.App):
         # SM_DRAW_SECONDARY_TICKS: We Draw Secondary (Intermediate) Ticks Between
         #                          The Main Ticks (Intervals)
 
-
         self.SpeedWindow1 = SM.SpeedMeter(Dialpanel,
                                           extrastyle=SM.SM_DRAW_HAND |
                                           SM.SM_DRAW_SECTORS |
@@ -549,14 +533,14 @@ class MyApp(wx.App):
         self.SpeedWindow1.SetNumberOfSecondaryTicks(5)
 
         # Set The Font For The Ticks Markers
-        self.SpeedWindow1.SetTicksFont(wx.Font(10, wx.SWISS, wx.NORMAL, wx.NORMAL))
+        self.SpeedWindow1.SetTicksFont(wx.Font(11, wx.SWISS, wx.NORMAL, wx.NORMAL))
                                        
         # Set The Text In The Center Of SpeedMeter
         self.SpeedWindow1.SetMiddleText("Km/h")
         # Assign The Colour To The Center Text
         self.SpeedWindow1.SetMiddleTextColour(wx.WHITE)
         # Assign A Font To The Center Text
-        self.SpeedWindow1.SetMiddleTextFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
+        self.SpeedWindow1.SetMiddleTextFont(wx.Font(14, wx.SWISS, wx.NORMAL, wx.BOLD))
 
         # Set The Colour For The Hand Indicator
         self.SpeedWindow1.SetHandColour(wx.Colour(255, 50, 0))
@@ -592,7 +576,7 @@ class MyApp(wx.App):
         ticks = [str(interval) for interval in intervals]
         self.SpeedWindow5.SetTicks(ticks)
         self.SpeedWindow5.SetTicksColour(wx.WHITE)
-        self.SpeedWindow5.SetTicksFont(wx.Font(10, wx.SWISS, wx.NORMAL, wx.NORMAL))
+        self.SpeedWindow5.SetTicksFont(wx.Font(11, wx.SWISS, wx.NORMAL, wx.NORMAL))
 
         self.SpeedWindow5.SetHandColour(wx.Colour(255, 50, 0))
 
@@ -604,13 +588,12 @@ class MyApp(wx.App):
 
         self.SpeedWindow5.SetMiddleText("rpm")
         self.SpeedWindow5.SetMiddleTextColour(wx.WHITE)
-        self.SpeedWindow5.SetMiddleTextFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
+        self.SpeedWindow5.SetMiddleTextFont(wx.Font(14, wx.SWISS, wx.NORMAL, wx.BOLD))
         self.SpeedWindow5.SetSpeedBackground(wx.Colour(0, 0, 0)) 
         
         self.SpeedWindow5.SetSpeedValue(.2)
         
 
-
         ####################################################################
         # This little bit of magic keeps the list the same size as the frame
         def OnPSize(e, win = Dialpanel):
@@ -619,15 +602,14 @@ class MyApp(wx.App):
             self.SpeedWindow5.SetSize(e.GetSize())
 
             w,h = self.frame.GetClientSizeTuple()
-            self.SpeedWindow1.SetDimensions(0,HOFFSET_LIST+10, w/2 ,h )
-            self.SpeedWindow5.SetDimensions(400,HOFFSET_LIST+10, w/2 , h )
+            self.SpeedWindow1.SetDimensions(0,HOFFSET_LIST+10, w/2-5 ,h )
+            self.SpeedWindow5.SetDimensions(w/2,HOFFSET_LIST+10, w/2-5 , h )
 
 
         Dialpanel.Bind(wx.EVT_SIZE,OnPSize)
         ####################################################################
 
-
-        self.nb.AddPage(Dialpanel, "Gauge")
+        self.nb.AddPage(Dialpanel, "Gauges")
 
        
     def TraceDebug(self,level,msg):
@@ -679,6 +661,7 @@ class MyApp(wx.App):
         #  self.SERTIMEOUT=self.config.getint("pyOBD","SERTIMEOUT")
         
         frame = wx.Frame(None, -1, "pyOBD-II for n900")
+        frame.ShowFullScreen(True) 
         self.frame=frame
 
         EVT_RESULT(self,self.OnResult,EVT_RESULT_ID)
@@ -690,7 +673,7 @@ class MyApp(wx.App):
         
         # Main notebook frames
         self.nb = wx.Notebook(frame, -1, style = wx.NB_TOP)
-        self.nb.SetFont(wx.FFont(17, wx.DEFAULT)) 
+        self.nb.SetFont(wx.FFont(16, wx.DEFAULT)) 
 
         self.status = self.MyListCtrl(self.nb, tID,style=wx.LC_REPORT|wx.SUNKEN_BORDER)
         self.status.InsertColumn(0, "Description",width=280)
@@ -700,7 +683,6 @@ class MyApp(wx.App):
         self.status.Append(["Cable version","---"]);
         self.status.Append(["COM port",self.COMPORT]);
 
-#m
         self.status.Append(["BT dev",self.btname]);
         
         self.nb.AddPage(self.status, "Status")
@@ -717,7 +699,6 @@ class MyApp(wx.App):
 
         self.build_DTC_page()
         self.build_dial_page()
-
         
         self.trace = self.MyListCtrl(self.nb, tID,style=wx.LC_REPORT|wx.SUNKEN_BORDER)
         self.trace.InsertColumn(0, "Level",width=70)
@@ -727,40 +708,47 @@ class MyApp(wx.App):
 
         # Setting up the menu.
         self.filemenu= wx.Menu()
-        self.filemenu.Append(ID_EXIT,"E&xit"," Terminate the program")
+        self.filemenu.Append(ID_FULLSCREEN,"FullScreen ON/OFF","FullScreen")
+        self.filemenu.AppendSeparator()
+        self.filemenu.Append(ID_EXIT,"Exit"," Terminate the program")
 
         self.settingmenu = wx.Menu()
         self.settingmenu.Append(ID_CONFIG,"Search and connect paired BT dongle"," Configure pyOBD")
+        self.settingmenu.AppendSeparator()
         self.settingmenu.Append(ID_RESET,"Connect to ECU"," Reopen and connect to device")
+        self.settingmenu.AppendSeparator()
         self.settingmenu.Append(ID_DISCONNECT,"Disconnect","Close connection to device")
 
-
         self.dtcmenu= wx.Menu()
         # tady toto nastavi automaticky tab DTC a provede akci
         self.dtcmenu.Append(ID_GETC  ,"Get DTCs",   " Get DTC Codes")
+        self.dtcmenu.AppendSeparator()
         self.dtcmenu.Append(ID_CLEAR ,"Clear DTC",  " Clear DTC Codes")
 
 #m        self.dtcmenu.Append(ID_LOOK  ,"Code Lookup"," Lookup DTC Codes")
 
         self.helpmenu = wx.Menu()
-        
         self.helpmenu.Append(ID_HELP_ABOUT        ,"About this program",   " Get DTC Codes")
+        self.helpmenu.AppendSeparator()
         self.helpmenu.Append(ID_HELP_ABOUT_Maemo  ,"About Maemo/n900",   " ")
+        self.helpmenu.AppendSeparator()
         self.helpmenu.Append(ID_HELP_VISIT_Maemo  ,"Visit MAEMO Thread"," ")
+        self.helpmenu.AppendSeparator()
         self.helpmenu.Append(ID_HELP_VISIT        ,"Visit program homepage"," Lookup DTC Codes")
         #self.helpmenu.Append(ID_HELP_ORDER        ,"Order OBD-II cables",  " Clear DTC Codes")
 
 
         # Creating the menubar.
         self.menuBar = wx.MenuBar()
-        self.menuBar.Append(self.filemenu,"&File") # Adding the "filemenu" to the MenuBar
-        self.menuBar.Append(self.settingmenu,"&OBD-II")
-        self.menuBar.Append(self.dtcmenu,"&Trouble codes")
-        self.menuBar.Append(self.helpmenu,"&Help")
+        self.menuBar.Append(self.filemenu,"\n File ") # Adding the "filemenu" to the MenuBar
+        self.menuBar.Append(self.settingmenu,"\n OBD-II ")
+        self.menuBar.Append(self.dtcmenu,"\n Trouble codes ")
+        self.menuBar.Append(self.helpmenu,"\n Help")
         
         frame.SetMenuBar(self.menuBar)  # Adding the MenuBar to the Frame content.
-        
-        frame.Bind(wx.EVT_MENU,self.OnExit,id=ID_EXIT)# attach the menu-event ID_EXIT to the   
+
+        frame.Bind(wx.EVT_MENU,self.OnFullScreen,id=ID_FULLSCREEN)         
+        frame.Bind(wx.EVT_MENU,self.OnExit,id=ID_EXIT) # attach the menu-event ID_EXIT to the   
         frame.Bind(wx.EVT_MENU,self.QueryClear,id=ID_CLEAR)
         frame.Bind(wx.EVT_MENU,self.Configure,id=ID_CONFIG)
         frame.Bind(wx.EVT_MENU,self.OpenPort,id=ID_RESET)
@@ -778,7 +766,7 @@ class MyApp(wx.App):
         self.SetTopWindow(frame)
 
         frame.Show(True)
-        frame.SetSize((520,400))
+        frame.SetSize((800,400))
         self.sensor_control_off()
         self.settingmenu.Enable(ID_RESET,False)
         self.settingmenu.Enable(ID_DISCONNECT,False)
@@ -807,17 +795,8 @@ class MyApp(wx.App):
         stringa = 'dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:/home/opt/pyobd/pyobd.txt'
         os.popen(stringa)
 
-        Text = """pyobd-0.9.2-16beta
+        Text = """pyobd-0.9.2-17beta
 Adapted to n900 by m750 at maemo.org
-Now work only with BT ELM OBD devices. 
-
-pyOBD does not recognize all error 
-codes. You could edit the file: 
-   /home/opt/obd2_codes.py  
-to add this error codes. 
-
-Sensors are logged in: 
-  /home/user/MyDocs/pyobd.log  
 """
 
         #self.HelpAboutMaemoDlg = wx.MessageDialog(self.frame, Text, 'About n900 adapting',wx.OK | wx.ICON_INFORMATION)
@@ -840,7 +819,6 @@ later version.
 """
 
 
-
 #  PyOBD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MEHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 # You should have received a copy of the GNU General Public License along with PyOBD; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
@@ -888,33 +866,30 @@ later version.
 
     def OnDial(self,event):
 
-	time.sleep(0.01)
 	wx.Yield()
 	data=event.data
-	print data
-	print data[:3]
-	if data[:3]=="kmh":
-		speed=int(event.data[3:])
-		print "speed: "+str(speed)
-		if speed>200:
-			speed=200
+	d1=data[:3]
+	d2=int(data[3:])
+	if d1=="kmh":
+		print "speed: "+str(d2)
+		if d2>200:
+			d2=200
 			self.SpeedWindow1.SetTicksColour(wx.RED)
 		else:
 			self.SpeedWindow1.SetTicksColour(wx.WHITE)
 
-		self.SpeedWindow1.SetSpeedValue(int(speed))
+		self.SpeedWindow1.SetSpeedValue(d2)
 
-	elif data[:3]=="rpm":
-		rpm=int(event.data[3:])
-		print "rpm: "+str(rpm)
-		if rpm>8000:
-			rpm=8000
+	elif d1=="rpm":
+		print "rpm: "+str(d2)
+		if d2>8000:
+			d2=8000
 			self.SpeedWindow5.SetTicksColour(wx.RED)
 		else:
 			self.SpeedWindow5.SetTicksColour(wx.WHITE)
-		rpm=rpm/1000.0
+		d2=d2/1000.0
 
-		self.SpeedWindow5.SetSpeedValue((rpm))
+		self.SpeedWindow5.SetSpeedValue(d2)
 
 
     def OnDisconnect(self,event): #disconnect connection to ECU
@@ -941,7 +916,6 @@ later version.
 
        
     def OpenPort(self,e):
-        
         if self.senprod: # signal current producers to finish
             self.senprod.stop()
         self.ThreadControl = 0    
@@ -950,10 +924,12 @@ later version.
         
         self.sensor_control_on()
         
+
     def GetDTC(self,e):
         self.nb.SetSelection(3)
         self.ThreadControl=2
         
+
     def AddDTC(self, code):
         self.dtc.InsertStringItem(0, "")
         self.dtc.SetStringItem(0, 0, code[0])
@@ -1031,8 +1007,6 @@ later version.
 
 # nome
 
-
-
         #target_name = "CB"
 
            # Loop a couple times in case the device/name isn't found the first time
@@ -1282,6 +1256,9 @@ later version.
             time.sleep(0.7)
 
 
+    def OnFullScreen(self,e = None):
+        self.frame.ShowFullScreen(not self.frame.IsFullScreen(), wx.FULLSCREEN_ALL)
+        
         
     def OnExit(self,e = None):
         import sys
